summaryrefslogtreecommitdiffstats
path: root/webkit/glue/webview_delegate.h
diff options
context:
space:
mode:
Diffstat (limited to 'webkit/glue/webview_delegate.h')
-rw-r--r--webkit/glue/webview_delegate.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/webkit/glue/webview_delegate.h b/webkit/glue/webview_delegate.h
index 59d4d95..a1a90d2 100644
--- a/webkit/glue/webview_delegate.h
+++ b/webkit/glue/webview_delegate.h
@@ -498,9 +498,10 @@ class WebViewDelegate : virtual public WebWidgetDelegate {
}
// Displays a JavaScript alert panel associated with the given view. Clients
// should visually indicate that this panel comes from JavaScript. The panel
// should have a single OK button.
- virtual void RunJavaScriptAlert(WebView* webview,
+ virtual void RunJavaScriptAlert(WebFrame* webframe,
const std::wstring& message) {
}
@@ -508,7 +509,7 @@ class WebViewDelegate : virtual public WebWidgetDelegate {
// Clients should visually indicate that this panel comes
// from JavaScript. The panel should have two buttons, e.g. "OK" and
// "Cancel". Returns true if the user hit OK, or false if the user hit Cancel.
- virtual bool RunJavaScriptConfirm(WebView* webview,
+ virtual bool RunJavaScriptConfirm(WebFrame* webframe,
const std::wstring& message) {
return false;
}
@@ -520,7 +521,7 @@ class WebViewDelegate : virtual public WebWidgetDelegate {
// panel when it is shown. If the user hit OK, returns true and fills result
// with the text in the box. The value of result is undefined if the user
// hit Cancel.
- virtual bool RunJavaScriptPrompt(WebView* webview,
+ virtual bool RunJavaScriptPrompt(WebFrame* webframe,
const std::wstring& message,
const std::wstring& default_value,
std::wstring* result) {
@@ -536,7 +537,7 @@ class WebViewDelegate : virtual public WebWidgetDelegate {
// that the navigation should continue, and Cancel means that the navigation
// should be cancelled, leaving the user on the current page. Returns true
// if the user hit OK, or false if the user hit Cancel.
- virtual bool RunBeforeUnloadConfirm(WebView* webview,
+ virtual bool RunBeforeUnloadConfirm(WebFrame* webframe,
const std::wstring& message) {
return true; // OK, continue to navigate away
}
@@ -498,9 +498,10 @@ class WebViewDelegate : virtual public WebWidgetDelegate {
}
// Displays a JavaScript alert panel associated with the given view. Clients
- // should visually indicate that this panel comes from JavaScript. The panel
+ // should visually indicate that this panel comes from JavaScript and some
+ // information about the originating frame (at least the domain). The panel
// should have a single OK button.